@@ -2,6 +2,7 @@ import copy
 import operator as op
 import pickle
 import unittest
+import warnings
 
 from pint import DimensionalityError, OffsetUnitCalculusError, UnitStrippedWarning
 from pint.compat import np
@@ -850,6 +851,16 @@ class TestNumpyUnclassified(TestNumpyMethods):
         q[0] = 1.0
         self.assertQuantityEqual(q, [0.001, 1, 2, 3] * self.ureg.m / self.ureg.mm)
 
+        # Check that this properly masks the first item without warning
+        q = self.ureg.Quantity(
+            np.ma.array([0.0, 1.0, 2.0, 3.0], mask=[False, True, False, False]), "m"
+        )
+        with warnings.catch_warnings(record=True) as w:
+            q[0] = np.ma.masked
+            # Check for no warnings
+            assert not w
+            assert q.mask[0]
+
     def test_iterator(self):
         for q, v in zip(self.q.flatten(), [1, 2, 3, 4]):
             self.assertEqual(q, v * self.ureg.m)
@@ -878,11 +889,24 @@ class TestNumpyUnclassified(TestNumpyMethods):
     def test_equal(self):
         x = self.q.magnitude
         u = self.Q_(np.ones(x.shape))
+        true = np.ones_like(x, dtype=np.bool_)
+        false = np.zeros_like(x, dtype=np.bool_)
 
         self.assertQuantityEqual(u, u)
         self.assertQuantityEqual(u == u, u.magnitude == u.magnitude)
         self.assertQuantityEqual(u == 1, u.magnitude == 1)
 
+        v = self.Q_(np.zeros(x.shape), "m")
+        w = self.Q_(np.ones(x.shape), "m")
+        self.assertNDArrayEqual(v == 1, false)
+        self.assertNDArrayEqual(
+            self.Q_(np.zeros_like(x), "m") == self.Q_(np.zeros_like(x), "s"), false,
+        )
+        self.assertNDArrayEqual(v == v, true)
+        self.assertNDArrayEqual(v == w, false)
+        self.assertNDArrayEqual(v == w.to("mm"), false)
+        self.assertNDArrayEqual(u == v, false)
+
     def test_shape(self):
         u = self.Q_(np.arange(12))
         u.shape = 4, 3
